@@ -1,6 +1,6 @@
 package Dancer::Logger::Log4perl;
 BEGIN {
-  $Dancer::Logger::Log4perl::VERSION = '0.7.0_02';
+  $Dancer::Logger::Log4perl::VERSION = '0.7.0_03';
 }
 
 # ABSTRACT: Dancer adapter for Log::Log4perl
@@ -59,7 +59,7 @@ Dancer::Logger::Log4perl - Dancer adapter for Log::Log4perl
 
 =head1 VERSION
 
-version 0.7.0_02
+version 0.7.0_03
 
 =head1 SYNOPSIS
 
@@ -98,7 +98,21 @@ e.g. the stealth loggers in case of a simplified interface.
 =head1 CONFIGURATION
 
 The configuration capabilities vary depending on the underlying library
-you have.
+you have, even though the following configurations are common:
+
+=over
+
+=item B<< no_init >>
+
+skip the initialisation phase of the logging module, assuming that it
+is performed elsewhere.
+
+=item B<< tiny >>
+
+allows you to decide whether L<Log::Log4perl> (when set to a false value) or
+L<Log::Log4perl::Tiny> (when set to a true value) should be used.
+
+=back
 
 =head2 Log::Log4perl
 
@@ -107,7 +121,7 @@ to pass a configuration:
 
 =over
 
-=item *
+=item B<< config_file >>
 
 via a configuration file, using the C<config_file> option:
 
@@ -115,7 +129,7 @@ via a configuration file, using the C<config_file> option:
    log4perl:
       config_file: log4perl.conf
 
-=item *
+=item B<< config >>
 
 via a straight configuration text, using the C<config> option:
 
@@ -131,38 +145,38 @@ via a straight configuration text, using the C<config> option:
 
 =back
 
-You can also decide to perform the configuration phase by yourself, directly
-inside the program. In this case, the C<no_init> option should come handy.
-
 =head2 Log::Log4perl::Tiny
 
 If all you have is L<Log::Log4perl::Tiny>, you can set some parameters:
 
 =over
 
-=item *
+=item B<< level >>
 
 the log C<level>
 
-=item *
+   logger: log4perl
+   log4perl:
+      tiny: 1
+      level: INFO
+
+=item B<< format >>
 
 the log C<format> (aliased to C<layout> as well)
 
+   logger: log4perl
+   log4perl:
+      tiny: 1
+      format: [%p] %m%n
+
 =back
 
-Again, you can decide to perform your own initialisation, in which case it
-is adviseable to use the C<no_init> option.
-
-=head1 INTERFACE
-
-=head2 Logging Facilities
+=begin hideme
 
 =over
 
 =item B<< new >>
 
-the object constructor.
-
 =item B<< debug >>
 
 =item B<< core >>
@@ -171,10 +185,10 @@ the object constructor.
 
 =item B<< error >>
 
-The four methods that a L<Dancer> logger must have.
-
 =back
 
+=end hideme
+
 =head1 AUTHOR
 
 Flavio Poletti <polettix@cpan.org>
